==> haskell-persistent-test-2.0.3.0-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-test
version: 2.0.3.0
id: persistent-test-2.0.3.0-56YX314Ld3eEhbZaMiYFid
key: persistent-test-2.0.3.0-56YX314Ld3eEhbZaMiYFid
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.
category: Database, Yesod
abi: 2a584ef00127127d520cc9d4b9dc3179
exposed: True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest HtmlTest Init
    LargeNumberTest MaxLenTest MigrationColumnLengthTest
    MigrationIdempotencyTest MigrationOnlyTest MigrationTest
    MpsNoPrefixTest PersistTestPetCollarType PersistTestPetType
    PersistUniqueTest PersistentTest PersistentTestModels PrimaryTest
    RawSqlTest ReadWriteTest Recursive RenameTest SumTypeTest
    TransactionLevelTest TreeTest UniqueTest UpsertTest
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-test-2.0.3.0
hs-libraries: HSpersistent-test-2.0.3.0-56YX314Ld3eEhbZaMiYFid
depends:
    HUnit-1.6.0.0-F7HqWS6YZw9Ctb1uJk5Q8g
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s base-4.12.0.0
    blaze-html-0.9.1.2-3rCj4yYYlH244V10MP4Bb5 bytestring-0.10.8.2
    conduit-1.3.1.2-H13fTqo9FiUDKKswU2xRAM containers-0.6.0.1
    exceptions-0.10.3-C2fkKAVjk4AA6i9Cl1i116
    hspec-2.7.1-1ym4rlU4DQD8tr1OT7RR0c
    hspec-expectations-0.8.2-1UIpFBzpGvZ3spIZyUQi5X
    monad-control-1.0.2.3-EQU08Q5uVAI5Qyu4idMrsU
    monad-logger-0.3.31-DFuwqaEK8YxLPzZA4ASxkU
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.10.4-LnXGfLIDM5NJTHtaWObP3n
    persistent-template-2.7.3-IjIUhUaUaKXDbCLSJYLjf1
    quickcheck-instances-0.3.22-Ez58aRTfGpq2RUB6bwkfd2
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-LMjNLq6jsSj2JdftiUxIvR
    unliftio-0.2.12-EZdNAvVHW1A5uRUDx4sbmX
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
haddock-interfaces: /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock
haddock-html: /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.0.3.0-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-test
version: 2.0.3.0
id: persistent-test-2.0.3.0-LWSybbKSnFL8OGJDYg7Qi0
key: persistent-test-2.0.3.0-LWSybbKSnFL8OGJDYg7Qi0
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.
category: Database, Yesod
abi: c8d5a06ffe111d94358009a33939c6d4
exposed: True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest HtmlTest Init
    LargeNumberTest MaxLenTest MigrationColumnLengthTest
    MigrationIdempotencyTest MigrationOnlyTest MigrationTest
    MpsNoPrefixTest PersistTestPetCollarType PersistTestPetType
    PersistUniqueTest PersistentTest PersistentTestModels PrimaryTest
    RawSqlTest ReadWriteTest Recursive RenameTest SumTypeTest
    TransactionLevelTest TreeTest UniqueTest UpsertTest
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-test-2.0.3.0
hs-libraries: HSpersistent-test-2.0.3.0-LWSybbKSnFL8OGJDYg7Qi0
depends:
    HUnit-1.6.0.0-F7HqWS6YZw9Ctb1uJk5Q8g
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s base-4.12.0.0
    blaze-html-0.9.1.2-3rCj4yYYlH244V10MP4Bb5 bytestring-0.10.8.2
    conduit-1.3.1.2-KNywdU6deAEKB3TItOoWtt containers-0.6.0.1
    exceptions-0.10.3-C2fkKAVjk4AA6i9Cl1i116
    hspec-2.7.1-1ym4rlU4DQD8tr1OT7RR0c
    hspec-expectations-0.8.2-1UIpFBzpGvZ3spIZyUQi5X
    monad-control-1.0.2.3-EQU08Q5uVAI5Qyu4idMrsU
    monad-logger-0.3.31-6NsHkoUGsUU6puDnRXD7Jc
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.10.4-FmLV1YMIfDTLIGh748uiF6
    persistent-template-2.7.3-53oDWX2RwscJ7Nb4nGV4kw
    quickcheck-instances-0.3.22-Ez58aRTfGpq2RUB6bwkfd2
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-LMjNLq6jsSj2JdftiUxIvR
    unliftio-0.2.12-EZdNAvVHW1A5uRUDx4sbmX
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
haddock-interfaces: /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock
haddock-html: /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
